@@ -2,9 +2,7 @@
 mod common;
 
 use common::OsoTest;
-use oso::errors::polar::{
-    ErrorKind as PolarErrorKind, PolarError, RuntimeError as PolarRuntimeError,
-};
+use oso::errors::polar::{ErrorKind, PolarError, RuntimeError};
 use oso::{Oso, OsoError, PolarClass, PolarValue};
 
 // TODO in all tests, check type of error & message
@@ -107,7 +105,7 @@ fn test_failing_inline_query() {
         Err(e @ OsoError::InlineQueryFailedError { .. }) => {
             assert_eq!(
                 format!("{}", e),
-                "Inline query failed 1 == 0 at line 2, column 3"
+                "Inline query failed 1 == 0 at line 2, column 4"
             )
         }
         Err(_) => panic!("returned unexpected error"),
@@ -134,10 +132,9 @@ fn test_attribute_does_not_exist() -> oso::Result<()> {
     )?;
     let error = query.next().unwrap().unwrap_err();
 
-    if let OsoError::Polar(PolarError {
-        kind: PolarErrorKind::Runtime(PolarRuntimeError::Application { msg, .. }),
-        ..
-    }) = &error
+    if let OsoError::Polar(PolarError(ErrorKind::Runtime(RuntimeError::Application {
+        msg, ..
+    }))) = &error
     {
         assert_eq!(msg, "Attribute bar not found on type Foo.");
     } else {
@@ -173,10 +170,9 @@ fn test_method_does_not_exist() -> oso::Result<()> {
     let mut query = oso.oso.query_rule("getmethod_b", (Foo, 1))?;
     let error = query.next().unwrap().unwrap_err();
 
-    if let OsoError::Polar(PolarError {
-        kind: PolarErrorKind::Runtime(PolarRuntimeError::Application { msg, .. }),
-        ..
-    }) = &error
+    if let OsoError::Polar(PolarError(ErrorKind::Runtime(RuntimeError::Application {
+        msg, ..
+    }))) = &error
     {
         assert_eq!(msg, "Method b not found on type Foo.");
     } else {
@@ -212,10 +208,9 @@ fn test_class_method_does_not_exist() -> oso::Result<()> {
     let mut query = oso.oso.query_rule("getmethod_b", (1,))?;
     let error = query.next().unwrap().unwrap_err();
 
-    if let OsoError::Polar(PolarError {
-        kind: PolarErrorKind::Runtime(PolarRuntimeError::Application { msg, .. }),
-        ..
-    }) = &error
+    if let OsoError::Polar(PolarError(ErrorKind::Runtime(RuntimeError::Application {
+        msg, ..
+    }))) = &error
     {
         assert_eq!(msg, "Class method b not found on type Foo.");
     } else {
